<template>
  <el-card shadow="never" class="aui-card--fill">
    <div class="mod-project-softwareTestOrder}">
      <zt-table-wraper query-url="/project/SoftwareTestOrder/page" delete-url="/project/SoftwareTestOrder/deleteOrder"
                       v-slot="{ table }">
        <el-form :inline="true" :model="dataForm" @keyup.enter.native="table.query()">
          <el-form-item>
            <el-input v-model="dataForm.softwareName" placeholder="请输入软件名称" clearable></el-input>
          </el-form-item>
          <el-form-item>
            <zt-dict v-model="dataForm.testBasis" dict="test_basis" placeholder="请选择测试依据" clearable></zt-dict>
          </el-form-item>
          <el-form-item>
            <zt-dict v-model="dataForm.testStandard" dict="test_standard" placeholder="请选择测试标准"
                     clearable></zt-dict>
          </el-form-item>
          <el-form-item>
            <zt-dict v-model="dataForm.articleNature" dict="article_nature" placeholder="请选择物品性质"
                     clearable></zt-dict>
          </el-form-item>
          <el-form-item>
            <zt-button type="query" @click="table.query()"/>
            <!--            <zt-button type="add" perm="project:add" @click="table.editHandle()"/>-->
            <zt-button type="primary" class="el-icon-edit" perm="project:add" @click="add()">新增</zt-button>
            <zt-button type="delete" perm="project:delete" @click="table.deleteHandle()"/>
          </el-form-item>
        </el-form>
        <el-table v-loading="table.dataLoading" :data="table.dataList" height="100px" v-adaptive="{bottomOffset:70}"
                  border @selection-change="table.selectionChangeHandle">
          <el-table-column type="selection" align="center" width="40"/>
          <el-table-column prop="softwareName" width="250px" label="软件名称"/>
          <el-table-column prop="code" width="270" label="委托单编号"/>
          <el-table-column prop="softwareIdentity" width="150px" label="项目标识"/>
          <zt-table-column-dict prop="testBasis" width="150px" label="测试依据" dict="test_basis"/>
          <zt-table-column-dict prop="testStandard" min-width="420" label="测试标准" dict="test_standard"/>
          <zt-table-column-dict prop="articleNature" width="120px" label="物品性质" dict="article_nature"/>
          <zt-table-column-handle :table="table" width="150px" edit-perm="project:update" delete-perm="project::delete">
            <template v-slot="{ row }">
              <zt-table-button size="small" type="primary"
                               @click="preview(row)">预览
              </zt-table-button>
            </template>
          </zt-table-column-handle>
        </el-table>
        <!-- 弹窗, 新增 / 修改 -->
        <add-or-update ref="addOrUpdate" @refreshDataList="table.query"/>
        <ProjectSelect ref="projectSelect"
                       @refreshDataList="table.query"
                       @setProjectInfo="openAddWin">
        </ProjectSelect>
        <ViewAccessory ref="ViewAccessory" :pageMarkerfun="SoftwareTestOrder"></ViewAccessory>
      </zt-table-wraper>
    </div>
  </el-card>
</template>

<script>
import AddOrUpdate from './SoftwareTestOrder-AddOrUpdate'
import ProjectSelect from "./Project-select.vue"
import ViewAccessory from '../../pages/view'

export default {
  data() {
    return {
      SoftwareTestOrder:'SoftwareTestOrder',
      dataForm: {
        testBasis: '',
        testType: '',
        testStandard: '',
        articleNature: '',
      }
    }
  },
  components: {
    AddOrUpdate,
    ProjectSelect,
    ViewAccessory
  },
  methods: {
    add() {
      this.$refs.projectSelect.$refs.dialog.init("software_test_order")
    },
    openAddWin(row) {
      console.log(row.id, 'row.id')
      this.$refs.addOrUpdate.$refs.dialog.init(null, {id: null, projectId: row.id})
    },
    preview(row){
      // let _this = this
      console.log(row,'preview(row)')

      console.log(this.$refs.ViewAccessory)
        this.$refs.ViewAccessory.setAccessory(row)

    }
  }
}
</script>

